RoleMap

Struct RoleMap 

pub struct RoleMap<F>(/* private fields */);
Associates roles with objects of type F, typically formulas.

Implementations

Source

impl<F: Default> RoleMap<F>

pub fn get_mut(&mut self, role: Role) -> &mut F

Return a mutable reference to the object associated with the role.

Source

impl<A, V> RoleMap<Vec<Fof<A, V>>>

pub fn join(self) -> Option<Fof<A, V>>

Merge all formulas to a big formula.

This returns None only if the role map contains no formula.